==> dokuwiki_0.0.20131208.orig.tar.gz: dokuwiki-2013-12-08/lib/plugins/usermanager/lang/bg/lang.php <==
<?php
/**
 * bulgarian language file
 *
 * @author Nikolay Vladimirov <nikolay@vladimiroff.com>
 * @author Viktor Usunov <usun0v@mail.bg>
 * @author Kiril <neohidra@gmail.com>
 */
$lang['menu']                  = 'Диспечер на потребителите';
$lang['noauth']                = '(удостоверяването на потребители не е налично)';
$lang['nosupport']             = '(управлението на потребители не се поддържа)';
$lang['badauth']               = 'невалиден механизъм за удостоверяване';
$lang['user_id']               = 'Потребител';
$lang['user_pass']             = 'Парола';
$lang['user_name']             = 'Истинско име';
$lang['user_mail']             = 'Електронна поща';
$lang['user_groups']           = 'Групи';
$lang['field']                 = 'Поле';
$lang['value']                 = 'Стойност';
$lang['add']                   = 'Добави';
$lang['delete']                = 'Изтрий';
$lang['delete_selected']       = 'Изтрий избраните';
$lang['edit']                  = 'Редактирай';
$lang['edit_prompt']           = 'Редактиране на потребителя';
$lang['modify']                = 'Запиши промените';
$lang['search']                = 'Търсене';
$lang['search_prompt']         = 'Търси';
$lang['clear']                 = 'Обновяване на търсенето';
$lang['filter']                = 'Филтър';
$lang['summary']               = 'Показване на потребители %1$d-%2$d от %3$d намерени. Общо %4$d потребителя.';
$lang['nonefound']             = 'Не са намерени потребители. Общо %d потребителя.';
$lang['delete_ok']             = '%d изтрити потребителя';
$lang['delete_fail']           = 'изтриването на %d се провали.';
$lang['update_ok']             = 'Обновяването на потребителя е успешно';
$lang['update_fail']           = 'Обновяването на потребителя се провали';
$lang['update_exists']         = 'Смяната на потребителското име се провали, въведеното потребителско име (%s) вече съществува (всички други промени ще бъдат приложени).';
$lang['start']                 = 'начало';
$lang['prev']                  = 'назад';
$lang['next']                  = 'напред';
$lang['last']                  = 'край';
$lang['edit_usermissing']      = 'Избраният потребител не е намерен, въведеното потребителско име може да е изтрито или променено другаде.';
$lang['user_notify']           = 'Уведомяване на потребителя';
$lang['note_notify']           = 'Ел. писмо се изпраща само ако бъде променена паролата на потребителя.';
$lang['note_group']            = 'Новите потребители биват добавяни към стандартната групата (%s) ако не е посочена друга.';
$lang['note_pass']             = 'Паролата ще бъде генерирана автоматично, ако оставите полето празно и функцията за уведомяване на потребителя е включена.';
$lang['add_ok']                = 'Добавянето на потребителя е успешно';
$lang['add_fail']              = 'Добавянето на потребителя се провали';
$lang['notify_ok']             = 'Изпратено е осведомително ел. писмо';
$lang['notify_fail']           = 'Изпращането на осведомително ел. писмо не е възможно';

==> dokuwiki_0.0.20140505.a+dfsg.orig.tar.gz: dokuwiki-2014-05-05a/lib/plugins/usermanager/lang/bg/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author Nikolay Vladimirov <nikolay@vladimiroff.com>
 * @author Viktor Usunov <usun0v@mail.bg>
 * @author Kiril <neohidra@gmail.com>
 */
$lang['menu']                  = 'Диспечер на потребителите';
$lang['noauth']                = '(удостоверяването на потребители не е налично)';
$lang['nosupport']             = '(управлението на потребители не се поддържа)';
$lang['badauth']               = 'невалиден механизъм за удостоверяване';
$lang['user_id']               = 'Потребител';
$lang['user_pass']             = 'Парола';
$lang['user_name']             = 'Истинско име';
$lang['user_mail']             = 'Електронна поща';
$lang['user_groups']           = 'Групи';
$lang['field']                 = 'Поле';
$lang['value']                 = 'Стойност';
$lang['add']                   = 'Добави';
$lang['delete']                = 'Изтрий';
$lang['delete_selected']       = 'Изтрий избраните';
$lang['edit']                  = 'Редактирай';
$lang['edit_prompt']           = 'Редактиране на потребителя';
$lang['modify']                = 'Запиши промените';
$lang['search']                = 'Търсене';
$lang['search_prompt']         = 'Търси';
$lang['clear']                 = 'Обновяване на търсенето';
$lang['filter']                = 'Филтър';
$lang['summary']               = 'Показване на потребители %1$d-%2$d от %3$d намерени. Общо %4$d потребителя.';
$lang['nonefound']             = 'Не са намерени потребители. Общо %d потребителя.';
$lang['delete_ok']             = '%d изтрити потребителя';
$lang['delete_fail']           = 'изтриването на %d се провали.';
$lang['update_ok']             = 'Обновяването на потребителя е успешно';
$lang['update_fail']           = 'Обновяването на потребителя се провали';
$lang['update_exists']         = 'Смяната на потребителското име се провали, въведеното потребителско име (%s) вече съществува (всички други промени ще бъдат приложени).';
$lang['start']                 = 'начало';
$lang['prev']                  = 'назад';
$lang['next']                  = 'напред';
$lang['last']                  = 'край';
$lang['edit_usermissing']      = 'Избраният потребител не е намерен, въведеното потребителско име може да е изтрито или променено другаде.';
$lang['user_notify']           = 'Уведомяване на потребителя';
$lang['note_notify']           = 'Имейл се изпраща само ако бъде променена паролата на потребителя.';
$lang['note_group']            = 'Новите потребители биват добавяни към стандартната групата (%s) ако не е посочена друга.';
$lang['note_pass']             = 'Паролата ще бъде генерирана автоматично, ако оставите полето празно и функцията за уведомяване на потребителя е включена.';
$lang['add_ok']                = 'Добавянето на потребителя е успешно';
$lang['add_fail']              = 'Добавянето на потребителя се провали';
$lang['notify_ok']             = 'Изпратено е осведомителен имейл';
$lang['notify_fail']           = 'Изпращането на осведомителен имейл не е възможно';
